/*
*************************************************************************************************
*		CM60010ACT6 65k Color Graphical LCD Display Driver (Samsung S6B33BC controller)
*										All Rights Reserved
* File name		: s6b33bc.h
* Programmer 	: John Leung, TechToys Co. Hong Kong
* Web presence  : www.TechToys.com.hk
* Note			: 
* Language		: Keil C (C51) compiler, Eval version 7.09 under uVision2 IDE v2.40
* Hardware		: AT89S8253-cLCD-STK1, & CM60010ACT6_BO
* Date			: 2nd Nov 2006 Version 1.0
*************************************************************************************************
*										DESCRIPTION
*
* This software module provides interface to CM60010ACT6 color graphical LCD module of 128*160
* Display controller chip is Samsung S6B33BC
* Module requires 3.3V DC supply to Vdd, LED backlight requires 6.2-6.5V, 15mA typical
*
* The LCD has been mount on a PCB with 2.00mm pinouts, pin id as follows:
* --------- Module															MCU -------------
* pin 1		GND 	- GND													GND
* pin 2		Vdd 	- 3.3V Supply											3.3V
* pin 3		NC (no connect)
* pin 4 	A0 		- (H:Data, L:Command)									P2.1
* pin 5		WR 		- active low, L:Write; use with RD pin					P2.2
* pin 6		RD 		- active low, L:Read; use with WR pin					P2.3
* pin 7-14  D7:D0 	- LCD_DATA 												P0
* pin 15	CS 		- chip select, low active								P2.4
* pin 16	BL_EN 	- backlight enable signal								P2.5
					  (high active, wired to LM2665M6 on the LCD module)
* pin 17	RST 	- reset, low active										P2.6
* pin 18	NC
* pin 19	LED+ 	- LED backlight, requires 6.2-6.5V, 15mA typical		VBL wired to IRLML6401
* pin 20	LED- 	- Cathode for LED-backlight, wired to GND				GND
***********************************************************************************************
*/


#ifndef _S6B33BC_H_
#define _S6B33BC_H_

typedef unsigned char 		INT8U;
typedef unsigned int		INT16U;
typedef unsigned char		BOOLEAN;

/*
***********************************************************************************************
* Pack RGB in 16 bits, for 65k color display mode
* [R4R3R2R1R0][G5G4G3G2G1G0][B4B3B2B1B0]
***********************************************************************************************
*/
#define RGB(r,g,b)	((INT16U)r<<11)+((INT16U)g<<5)+(INT8U)b

#define PIXEL_FONT_EN	1
#if		PIXEL_FONT_EN
#define MAX_FONT_WIDTH 	8
typedef struct _font
	{
		INT8U fontWidth;
		INT8U fontBody[MAX_FONT_WIDTH];
	}font;
#endif

/*
***********************************************************************************************
*								Pin definition, Keil C specific
*								Hardware: AT89S8253-cLCD-STK1
***********************************************************************************************
*/

sbit	cDISP_A0=		P2^1;
sbit	cDISP_WR=		P2^2;
sbit 	cDISP_RD=		P2^3;	
sbit 	cDISP_CS=		P2^4;	
sbit	cDISP_LM2665_SW=P2^5;
sbit	cDISP_RST=		P2^6;
sbit	cDISP_BL_PWR=	P2^7;

#define cDISP_DATA		P0

/*
***********************************************************************************************
*										GLOBAL CONSTANTS
***********************************************************************************************
*/

#define MAX_ROW_PIXEL		160		//MAX_ROW_PIXEL the physical matrix length (y dir, downward)									
#define MAX_COL_PIXEL		128		//MAX_COL_PIXEL the physical matrix width (x dir, left->right)
#define ENABLE				1
#define DISABLE				0

/*
***********************************************************************************************
*									FUNCTION PROTOTYPES
***********************************************************************************************
*/
void cDispInit(void);
void cDispSwitch(BOOLEAN sw);
void cDispClr(INT16U color);
void cDispSetPixel(INT8U x, INT8U y, INT16U color);
void cDisprPatAt(INT8U x, INT8U y, INT16U *pPat);
#if PIXEL_FONT_EN
void cDispStrAt(INT8U x, INT8U y, INT8U *pStr, INT8U fontSpace, INT16U color);
#endif
void cDispSetContrast1(INT8U contrast);

/*
***********************************************************************************************
*									FUNCTION PROTOTYPES
*									 HARDWARE SPECIFIC
***********************************************************************************************
*/
void cDispInitPort(void);
void cDispWrCmd(INT8U cmd);
void cDispWrDat(INT8U dat);
void cDispBackLite(BOOLEAN ctrl);
void cDispReset(void);
#endif
